# STRandR (SpoopyTim RandR)
An xrandr based python utility to manage multiple monitors (with extra functionality for KDE)

## Why this exists
Regular configuration via xrandr is clunky and non persistent, if you want to keep changes you are forced to add a bunch of commands to a shell script file and run them on startup.

While you still need to persist your config using similar methods with this tool, the configuration language is easier to understand and can be beneficial if you have multiple display configurations.

Additionally X11 does not natively support per-screen scaling (afaik), this provides the functionality to set that based on resolution and override based on connected display.

The inspiration to build such a tool comes from [this thread](https://unix.stackexchange.com/questions/596887/how-to-scale-the-resolution-display-of-the-desktop-and-or-applications) on StackExchange and my own setup (2x 1920x1080, 1x 3840x2160) where scaling was a major annoyance.

## Usage

### Installation

```bash
pip install strandr --index-url https://git.horizonapp.net/api/v4/projects/90/packages/pypi/simple
```

*If for some reason you have this as part of another python project and are using the basic `requrements.txt` format for dependencies, you will need to add `--index-url https://git.horizonapp.net/api/v4/projects/90/packages/pypi/simple` to the top of your requirements.txt. This is a limitation of Gitlab as this package is only available on this registry*

### Generate a new strandr config from your existing xrandr config
```bash
strandr --generate > config.toml
```

### Preview changes before making them
```bash
strandr --config config.toml --dry-run
```

### Execute your config
```bash
strandr --config config.toml
```

### Execute your config (and replace plasmashell for KDE)
```bash
strandr --config config.toml --replace-plasmashell
```
*This was purely implemented for convenience, the underlying functionality is roughly equivalent to `nohup plasmashell --replace` right after the changes take effect*

### Show Help
```bash
strandr --help
```

## How to persist between sessions

Typically you can use your `~/.profile` or `~/.xprofile` to automatically run scripts on login, however your operating system might have systems in place to handle autostart differently.

See more [on the archlinux wiki](https://wiki.archlinux.org/title/Autostarting) (covers a wide variety of setups, not just arch-based)

# Issues

## If you have an account

Create an issue if you have a bug to report or a feature to suggest (I'm open to ideas).

Theres no issue format because this is a relatively simple project but remember to keep your issue concise and well documented as to reduce time wasted asking for more information.

If its a feature request, provide a detailed explanation (where appropriate) of what you would like to see in the tool, and optionally any references in other similar tools.

## Otherwise

Join my [discord server](https://spoopydev.com/discord) and ping me wherever